@@ -139,6 +139,8 @@ standardParsers = [
                                         Right es -> es }
    )),
 
+ -- EVENT_SHUTDOWN is replaced by EVENT_CAP_DELETE and GHC 7.6+
+ -- no longer generate the event; should be removed at some point
  (simpleEvent EVENT_SHUTDOWN Shutdown),
 
  (simpleEvent EVENT_REQUEST_SEQ_GC RequestSeqGC),
@@ -155,6 +157,70 @@ standardParsers = [
 
  (simpleEvent EVENT_GC_END EndGC),
 
+ (simpleEvent EVENT_GC_GLOBAL_SYNC GlobalSyncGC),
+
+ (FixedSizeParser EVENT_GC_STATS_GHC (sz_capset + 2 + 5*8 + 4) (do  -- (heap_capset, generation, copied_bytes, slop_bytes, frag_bytes, par_n_threads, par_max_copied, par_tot_copied)
+      heapCapset   <- getE
+      gen          <- getE :: GetEvents Word16
+      copied       <- getE :: GetEvents Word64
+      slop         <- getE :: GetEvents Word64
+      frag         <- getE :: GetEvents Word64
+      parNThreads  <- getE :: GetEvents Word32
+      parMaxCopied <- getE :: GetEvents Word64
+      parTotCopied <- getE :: GetEvents Word64
+      return GCStatsGHC{ gen = fromIntegral gen
+                       , parNThreads = fromIntegral parNThreads
+                       , ..}
+ )),
+
+ (FixedSizeParser EVENT_HEAP_ALLOCATED (sz_capset + 8) (do  -- (heap_capset, alloc_bytes)
+      heapCapset <- getE
+      allocBytes <- getE
+      return HeapAllocated{..}
+ )),
+
+ (FixedSizeParser EVENT_HEAP_SIZE (sz_capset + 8) (do  -- (heap_capset, size_bytes)
+      heapCapset <- getE
+      sizeBytes  <- getE
+      return HeapSize{..}
+ )),
+
+ (FixedSizeParser EVENT_HEAP_LIVE (sz_capset + 8) (do  -- (heap_capset, live_bytes)
+      heapCapset <- getE
+      liveBytes  <- getE
+      return HeapLive{..}
+ )),
+
+ (FixedSizeParser EVENT_HEAP_INFO_GHC (sz_capset + 2 + 4*8) (do  -- (heap_capset, n_generations, max_heap_size, alloc_area_size, mblock_size, block_size)
+      heapCapset    <- getE
+      gens          <- getE :: GetEvents Word16
+      maxHeapSize   <- getE :: GetEvents Word64
+      allocAreaSize <- getE :: GetEvents Word64
+      mblockSize    <- getE :: GetEvents Word64
+      blockSize     <- getE :: GetEvents Word64
+      return HeapInfoGHC{gens = fromIntegral gens, ..}
+ )),
+
+ (FixedSizeParser EVENT_CAP_CREATE (sz_cap) (do  -- (cap)
+      cap <- getE :: GetEvents CapNo
+      return CapCreate{cap = fromIntegral cap}
+ )),
+
+ (FixedSizeParser EVENT_CAP_DELETE (sz_cap) (do  -- (cap)
+      cap <- getE :: GetEvents CapNo
+      return CapDelete{cap = fromIntegral cap}
+ )),
+
+ (FixedSizeParser EVENT_CAP_DISABLE (sz_cap) (do  -- (cap)
+      cap <- getE :: GetEvents CapNo
+      return CapDisable{cap = fromIntegral cap}
+ )),
+
+ (FixedSizeParser EVENT_CAP_ENABLE (sz_cap) (do  -- (cap)
+      cap <- getE :: GetEvents CapNo
+      return CapEnable{cap = fromIntegral cap}
+ )),
+
  (FixedSizeParser EVENT_CAPSET_CREATE (sz_capset + sz_capset_type) (do -- (capset, capset_type)
       cs <- getE
       ct <- fmap mkCapsetType getE
@@ -313,16 +379,17 @@ ghc7Parsers = [
       return CreateSparkThread{sparkThread=st}
    )),
 
- (FixedSizeParser EVENT_SPARK_COUNTERS (7*8) (do -- (crt,dud,ovf,cnv,fiz,gcd,rem)
+ (FixedSizeParser EVENT_SPARK_COUNTERS (7*8) (do -- (crt,dud,ovf,cnv,gcd,fiz,rem)
       crt <- getE :: GetEvents Word64
       dud <- getE :: GetEvents Word64
       ovf <- getE :: GetEvents Word64
       cnv <- getE :: GetEvents Word64
-      fiz <- getE :: GetEvents Word64
       gcd <- getE :: GetEvents Word64
+      fiz <- getE :: GetEvents Word64
       rem <- getE :: GetEvents Word64
       return SparkCounters{sparksCreated    = crt, sparksDud       = dud,
                            sparksOverflowed = ovf, sparksConverted = cnv,
+                           -- Warning: order of fiz and gcd reversed!
                            sparksFizzled    = fiz, sparksGCd       = gcd,
                            sparksRemaining  = rem}
    )),
@@ -656,6 +723,26 @@ showEventInfo spec =
           printf "GC idle"
         GCDone ->
           printf "GC done"
+        GlobalSyncGC ->
+          printf "all caps stopped for GC"
+        GCStatsGHC{..} ->
+          printf "GC stats for heap capset %d: generation %d, %d bytes copied, %d bytes slop, %d bytes fragmentation, %d par threads, %d bytes max par copied, %d bytes total par copied" heapCapset gen copied slop frag parNThreads parMaxCopied parTotCopied
+        HeapAllocated{..} ->
+          printf "allocated on heap capset %d: %d total bytes till now" heapCapset allocBytes
+        HeapSize{..} ->
+          printf "size of heap capset %d: %d bytes" heapCapset sizeBytes
+        HeapLive{..} ->
+          printf "live data in heap capset %d: %d bytes" heapCapset liveBytes
+        HeapInfoGHC{..} ->
+          printf "heap stats for heap capset %d: generations %d, %d bytes max heap size, %d bytes alloc area size, %d bytes mblock size, %d bytes block size" heapCapset gens maxHeapSize allocAreaSize mblockSize blockSize
+        CapCreate{cap} ->
+          printf "created cap %d" cap
+        CapDelete{cap} ->
+          printf "deleted cap %d" cap
+        CapDisable{cap} ->
+          printf "disabled cap %d" cap
+        CapEnable{cap} ->
+          printf "enabled cap %d" cap
         Message msg ->
           msg
         UserMessage msg ->
@@ -827,6 +914,7 @@ eventTypeNum e = case e of
     ThreadLabel {}  -> EVENT_THREAD_LABEL
     StartGC {} -> EVENT_GC_START
     EndGC {} -> EVENT_GC_END
+    GlobalSyncGC {} -> EVENT_GC_GLOBAL_SYNC
     RequestSeqGC {} -> EVENT_REQUEST_SEQ_GC
     RequestParGC {} -> EVENT_REQUEST_PAR_GC
     CreateSparkThread {} -> EVENT_CREATE_SPARK_THREAD
@@ -845,6 +933,15 @@ eventTypeNum e = case e of
     GCIdle {} -> EVENT_GC_IDLE
     GCWork {} -> EVENT_GC_WORK
     GCDone {} -> EVENT_GC_DONE
+    GCStatsGHC{} -> EVENT_GC_STATS_GHC
+    HeapAllocated{} -> EVENT_HEAP_ALLOCATED
+    HeapSize{} -> EVENT_HEAP_SIZE
+    HeapLive{} -> EVENT_HEAP_LIVE
+    HeapInfoGHC{} -> EVENT_HEAP_INFO_GHC
+    CapCreate{} -> EVENT_CAP_CREATE
+    CapDelete{} -> EVENT_CAP_DELETE
+    CapDisable{} -> EVENT_CAP_DISABLE
+    CapEnable{} -> EVENT_CAP_ENABLE
     CapsetCreate {} -> EVENT_CAPSET_CREATE
     CapsetDelete {} -> EVENT_CAPSET_DELETE
     CapsetAssignCap {} -> EVENT_CAPSET_ASSIGN_CAP
@@ -938,8 +1035,9 @@ putEventSpec (SparkCounters crt dud ovf cnv fiz gcd rem) = do
     putE dud
     putE ovf
     putE cnv
-    putE fiz
+    -- Warning: order of fiz and gcd reversed!
     putE gcd
+    putE fiz
     putE rem
 
 putEventSpec SparkCreate = do
@@ -996,6 +1094,51 @@ putEventSpec GCDone = do
 putEventSpec EndGC = do
     return ()
 
+putEventSpec GlobalSyncGC = do
+    return ()
+
+putEventSpec GCStatsGHC{..} = do
+    putE heapCapset
+    putE gen
+    putE copied
+    putE slop
+    putE frag
+    putE parNThreads
+    putE parMaxCopied
+    putE parTotCopied
+
+putEventSpec HeapAllocated{..} = do
+    putE heapCapset
+    putE allocBytes
+
+putEventSpec HeapSize{..} = do
+    putE heapCapset
+    putE sizeBytes
+
+putEventSpec HeapLive{..} = do
+    putE heapCapset
+    putE liveBytes
+
+putEventSpec HeapInfoGHC{..} = do
+    putE heapCapset
+    putE gens
+    putE maxHeapSize
+    putE allocAreaSize
+    putE mblockSize
+    putE blockSize
+
+putEventSpec CapCreate{cap} = do
+    putCap cap
+
+putEventSpec CapDelete{cap} = do
+    putCap cap
+
+putEventSpec CapDisable{cap} = do
+    putCap cap
+
+putEventSpec CapEnable{cap} = do
+    putCap cap
+
 putEventSpec (CapsetCreate cs ct) = do
     putE cs
     putE $ case ct of
